@@ -1,6 +1,6 @@
-use libc::{c_void, intptr_t, uintptr_t};
+use libc::{intptr_t, uintptr_t};
 
-pub use libc::{c_char, c_int, c_long};
+pub use libc::{c_char, c_int, c_long, c_void};
 pub use value::{Value, ValueType};
 
 pub type Id = uintptr_t;
